SupabaseAdapter class
Supabase adapter for SyncLayer
Syncs data with Supabase PostgreSQL tables.
Example:
await SyncLayer.init(
SyncConfig(
customBackendAdapter: SupabaseAdapter(
client: Supabase.instance.client,
),
collections: ['todos', 'users'],
),
);
- Implemented types
Constructors
- SupabaseAdapter({required SupabaseClient client})
Properties
- client → SupabaseClient
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
delete(
{required String collection, required String recordId}) → Future< void> -
Delete data on backend
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pull(
{required String collection, DateTime? since, int? limit, int? offset, SyncFilter? filter}) → Future< List< SyncRecord> > -
Pull data from backend with optional pagination and filtering
override
-
push(
{required String collection, required String recordId, required Map< String, dynamic> data, required DateTime timestamp}) → Future<void> -
Push data to backend
override
-
pushDelta(
{required String collection, required String recordId, required Map< String, dynamic> delta, required int baseVersion, required DateTime timestamp}) → Future<void> -
Push delta (partial update) to backend.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
updateAuthToken(
String token) → void -
Update authentication token
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited