RealtimeSyncManager class

Real-time sync manager that handles WebSocket-based synchronization

Constructors

RealtimeSyncManager({required WebSocketService websocketService, required LocalStorage localStorage, required ConflictResolver conflictResolver, required List<String> collections})

Properties

events Stream<SyncEvent>
Stream of real-time sync events
no setter
hashCode int
The hash code for this object.
no setterinherited
isActive bool
Check if real-time sync is active
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() Future<void>
Dispose resources
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendChange({required MessageType type, required String collection, required String recordId, Map<String, dynamic>? data}) → void
Send local change to server via WebSocket
start() Future<void>
Start real-time sync
stop() Future<void>
Stop real-time sync
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited