WebSocketMessage class

WebSocket message structure

Constructors

WebSocketMessage({required MessageType type, String? collection, String? recordId, Map<String, dynamic>? data, DateTime? timestamp, Map<String, dynamic>? metadata})
WebSocketMessage.fromJson(Map<String, dynamic> json)
factory

Properties

collection String?
final
data Map<String, dynamic>?
final
hashCode int
The hash code for this object.
no setterinherited
metadata Map<String, dynamic>?
final
recordId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp DateTime?
final
type MessageType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited