ConflictResolvers class
Pre-built custom conflict resolvers for common scenarios.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
deepMerge(
) → CustomConflictResolverCallback - Deep merge: recursively merges nested objects.
-
fieldLevelLastWriteWins(
) → CustomConflictResolverCallback - Field-level last-write-wins: each field independently uses most recent.
-
maxValue(
List< String> numericFields) → CustomConflictResolverCallback - Takes the maximum value for numeric fields.
-
mergeArrays(
List< String> arrayFields) → CustomConflictResolverCallback - Merges arrays from both versions, removing duplicates.
-
mergeFields(
List< String> fieldsToMerge) → CustomConflictResolverCallback - Merges specific fields from local, keeps rest from remote.
-
sumNumbers(
List< String> numericFields) → CustomConflictResolverCallback - Sums numeric fields from both versions.